goutil

package module
v0.0.0-...-c2f863f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 5, 2012 License: MIT Imports: 1 Imported by: 0

README

goutil

Goutil is a shameless attempt to port over concepts from Python/Ruby to Go with no real consideration made for the different design decisions at work in the two languages.

This is still in the pre-alpha stage of development, so expect things to change at random.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NilOrDie

func NilOrDie(err error)

Types

type Data

type Data interface{}

Store whatever Data

type Number

type Number int64

Change this to float if you want to use floats

Directories

Path Synopsis

Jump to